@@ -1,11 +1,9 @@
-#[macro_use]
-extern crate run_script;
-
+use run_script;
 use run_script::ScriptOptions;
 
 fn main() {
     // simple call to run script with only the script text
-    let (code, output, error) = run_script!(
+    let (code, output, error) = run_script::run_script!(
         r#"
          echo "Test"
          exit 0
@@ -19,7 +17,7 @@ fn main() {
 
     // run script invoked with the script text and options
     let options = ScriptOptions::new();
-    let (code, output, error) = run_script!(
+    let (code, output, error) = run_script::run_script!(
         r#"
          echo "Test"
          exit 0
@@ -34,7 +32,7 @@ fn main() {
 
     // run script invoked with all arguments
     let options = ScriptOptions::new();
-    let (code, output, error) = run_script!(
+    let (code, output, error) = run_script::run_script!(
         r#"
          echo "Test"
          exit 0
@@ -49,7 +47,7 @@ fn main() {
     println!("Error: {}", error);
 
     // spawn_script! works the same as run_script! but returns the child process handle
-    let child = spawn_script!(
+    let child = run_script::spawn_script!(
         r#"
          echo "Test"
          exit 0
