@@ -7,6 +7,7 @@
     asm_sub_register,
     bad_asm_style,
     bindings_with_variant_name,
+    break_with_label_and_loop,
     cenum_impl_drop_cast,
     clashing_extern_declarations,
     coherence_leak_check,
@@ -17,11 +18,16 @@
     const_item_mutation,
     dead_code,
     deprecated,
+    deprecated_cfg_attr_crate_type_name,
     deprecated_in_future,
+    deprecated_where_clause_location,
+    deref_into_dyn_supertrait,
     deref_nullptr,
     drop_bounds,
+    duplicate_macro_attributes,
     dyn_drop,
     ellipsis_inclusive_range_patterns,
+    enum_intrinsics_non_enums,
     explicit_outlives_requirements,
     exported_private_dependencies,
     forbidden_lint_groups,
@@ -35,6 +41,7 @@
     indirect_structural_match,
     ineffective_unstable_trait_impl,
     inline_no_sanitize,
+    invalid_atomic_ordering,
     invalid_doc_attributes,
     invalid_type_param_default,
     invalid_value,
@@ -50,8 +57,9 @@
     missing_docs,
     missing_fragment_specifier,
     mixed_script_confusables,
-    mutable_borrow_reservation_conflict,
     mutable_transmutes,
+    named_arguments_used_positionally,
+    named_asm_labels,
     no_mangle_const_items,
     no_mangle_generic_items,
     non_ascii_idents,
@@ -73,6 +81,7 @@
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
     redundant_semicolons,
+    repr_transparent_external_private_fields,
     rust_2021_incompatible_closure_captures,
     rust_2021_incompatible_or_patterns,
     rust_2021_prefixes_incompatible_syntax,
@@ -80,7 +89,10 @@
     semicolon_in_expressions_from_macros,
     soft_unstable,
     stable_features,
+    suspicious_auto_trait_impls,
     temporary_cstring_as_ptr,
+    text_direction_codepoint_in_comment,
+    text_direction_codepoint_in_literal,
     trivial_bounds,
     trivial_casts,
     trivial_numeric_casts,
@@ -90,6 +102,7 @@
     uncommon_codepoints,
     unconditional_panic,
     unconditional_recursion,
+    unexpected_cfgs,
     uninhabited_static,
     unknown_crate_types,
     unnameable_test_items,
@@ -101,9 +114,9 @@
     unstable_features,
     unstable_name_collisions,
     unsupported_calling_conventions,
-    unsupported_naked_functions,
     unused_allocation,
     unused_assignments,
+    unused_assignments,
     unused_attributes,
     unused_braces,
     unused_comparisons,
@@ -115,6 +128,7 @@
     unused_imports,
     unused_labels,
     unused_lifetimes,
+    unused_macro_rules,
     unused_macros,
     unused_must_use,
     unused_mut,
@@ -122,7 +136,9 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
-    useless_deprecated
+    useless_deprecated,
+    where_clauses_object_safety,
+    while_true
 )]
 #![warn(macro_use_extern_crate, unknown_lints)]
 #![allow(
